PrincipalIdentity class

Implemented types
Annotations

Constructors

PrincipalIdentity({required String id, required String username, required String name, String? email, String? phone})
const
PrincipalIdentity.fromJson(Map<String, Object?> json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
name String
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override